==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/EmailserverprofileCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Emailserverprofile;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.EmailserverprofileRequest;
import microsoft.dynamics.crm.entity.request.MailboxRequest;
import microsoft.dynamics.crm.entity.request.OrganizationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.TracelogRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class EmailserverprofileCollectionRequest extends CollectionPageEntityRequest<Emailserverprofile, EmailserverprofileRequest>{

    protected ContextPath contextPath;

    public EmailserverprofileCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Emailserverprofile.class, cp -> new EmailserverprofileRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public MailboxCollectionRequest emailserverprofile_mailbox() {
        return new MailboxCollectionRequest(contextPath.addSegment("emailserverprofile_mailbox"), Optional.empty());
    }

    public MailboxRequest emailserverprofile_mailbox(String mailboxid) {
        return new MailboxRequest(contextPath.addSegment("emailserverprofile_mailbox").addKeys(new NameValue(mailboxid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest emailserverprofile_asyncoperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("emailserverprofile_asyncoperations"), Optional.empty());
    }

    public AsyncoperationRequest emailserverprofile_asyncoperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("emailserverprofile_asyncoperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest emailserverprofile_bulkdeletefailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures"), Optional.empty());
    }

    public BulkdeletefailureRequest emailserverprofile_bulkdeletefailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public OrganizationCollectionRequest emailServerProfile_Organization() {
        return new OrganizationCollectionRequest(contextPath.addSegment("EmailServerProfile_Organization"), Optional.empty());
    }

    public OrganizationRequest emailServerProfile_Organization(String organizationid) {
        return new OrganizationRequest(contextPath.addSegment("EmailServerProfile_Organization").addKeys(new NameValue(organizationid.toString())), Optional.empty());
    }

    public TracelogCollectionRequest tracelog_EmailServerProfile() {
        return new TracelogCollectionRequest(contextPath.addSegment("tracelog_EmailServerProfile"), Optional.empty());
    }

    public TracelogRequest tracelog_EmailServerProfile(String tracelogid) {
        return new TracelogRequest(contextPath.addSegment("tracelog_EmailServerProfile").addKeys(new NameValue(tracelogid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest emailServerProfile_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("EmailServerProfile_Annotation"), Optional.empty());
    }

    public AnnotationRequest emailServerProfile_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("EmailServerProfile_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatematchingrecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatematchingrecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest emailServerProfile_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("EmailServerProfile_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest emailServerProfile_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("EmailServerProfile_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatebaserecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatebaserecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/EmailserverprofileCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Emailserverprofile;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.EmailserverprofileRequest;
import microsoft.dynamics.crm.entity.request.MailboxRequest;
import microsoft.dynamics.crm.entity.request.OrganizationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.TracelogRequest;

public class EmailserverprofileCollectionRequest extends CollectionPageEntityRequest<Emailserverprofile, EmailserverprofileRequest>{

    protected ContextPath contextPath;

    public EmailserverprofileCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Emailserverprofile.class, cp -> new EmailserverprofileRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public MailboxCollectionRequest emailserverprofile_mailbox() {
        return new MailboxCollectionRequest(contextPath.addSegment("emailserverprofile_mailbox"), Optional.empty());
    }

    public MailboxRequest emailserverprofile_mailbox(String mailboxid) {
        return new MailboxRequest(contextPath.addSegment("emailserverprofile_mailbox").addKeys(new NameValue(mailboxid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest emailserverprofile_asyncoperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("emailserverprofile_asyncoperations"), Optional.empty());
    }

    public AsyncoperationRequest emailserverprofile_asyncoperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("emailserverprofile_asyncoperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest emailserverprofile_bulkdeletefailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures"), Optional.empty());
    }

    public BulkdeletefailureRequest emailserverprofile_bulkdeletefailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("emailserverprofile_bulkdeletefailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public OrganizationCollectionRequest emailServerProfile_Organization() {
        return new OrganizationCollectionRequest(contextPath.addSegment("EmailServerProfile_Organization"), Optional.empty());
    }

    public OrganizationRequest emailServerProfile_Organization(String organizationid) {
        return new OrganizationRequest(contextPath.addSegment("EmailServerProfile_Organization").addKeys(new NameValue(organizationid.toString())), Optional.empty());
    }

    public TracelogCollectionRequest tracelog_EmailServerProfile() {
        return new TracelogCollectionRequest(contextPath.addSegment("tracelog_EmailServerProfile"), Optional.empty());
    }

    public TracelogRequest tracelog_EmailServerProfile(String tracelogid) {
        return new TracelogRequest(contextPath.addSegment("tracelog_EmailServerProfile").addKeys(new NameValue(tracelogid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest emailServerProfile_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("EmailServerProfile_Annotation"), Optional.empty());
    }

    public AnnotationRequest emailServerProfile_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("EmailServerProfile_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatematchingrecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatematchingrecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatematchingrecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest emailServerProfile_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("EmailServerProfile_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest emailServerProfile_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("EmailServerProfile_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest emailserverprofile_duplicatebaserecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord"), Optional.empty());
    }

    public DuplicaterecordRequest emailserverprofile_duplicatebaserecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("emailserverprofile_duplicatebaserecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}
